@@ -13,9 +13,9 @@
 /* Has LIBCRYPT */
 #undef HAVE_LIBCRYPT
 
-/* HAS DB VER 2 */
-#undef USE_DB2
-
 #ifdef USE_LOGAUTH
 #define LOG_AUTHPRIV (4<<3)
 #endif
+
+/* DB_DIR defines where to put DB cache file and map temp files */
+#undef DB_DIR
